@@ -41,10 +41,18 @@ class PriceAwareHours(Hours):
     def non_hours(self) -> list:
         return self._core.non_hours
 
+    @non_hours.setter
+    def non_hours(self, val):
+        pass
+
     @property
     def caution_hours(self) -> list:
         return self._core.caution_hours
 
+    @caution_hours.setter
+    def caution_hours(self, val):
+        pass
+
     @property
     def absolute_top_price(self):
         return self._core.options.absolute_top_price
