@@ -2,6 +2,7 @@ from dataclasses import dataclass, field
 from datetime import datetime
 
 from ..locale.free_charge import FreeChargePattern
+from ...models.locale.price import LocalePrice
 from .querytypes.const import (
 HOURLY,
 QUARTER_HOURLY
@@ -10,7 +11,6 @@ from .querytypes.querytypes import(
 LocaleQuery
 )
 
-
 @dataclass(frozen=True)
 class Locale_Type:
     observed_peak: str
@@ -20,6 +20,7 @@ class Locale_Type:
     peak_cycle: str = HOURLY
     #converted: bool = False #transition key to remove sql-dependency
     is_quarterly: bool = field(init=False, repr=False)
+    price: LocalePrice = field(init=False)
 
     def free_charge(self, mockdt: datetime=datetime.min) -> bool:
         if self.free_charge_pattern is None:
